@@ -1,29 +1,16 @@
 /*
-  Copyright (c) 2014-2019 Montel Laurent <montel@kde.org>
+  SPDX-FileCopyrightText: 2014-2022 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "lineeditwithautocorrectiontest.h"
-#include <PimCommon/LineEditWithAutoCorrection>
 #include "../autocorrection.h"
+#include <PimCommon/LineEditWithAutoCorrection>
 #include <QTest>
 #include <qtestkeyboard.h>
 
-LineEditWithAutocorrectionTest::LineEditWithAutocorrectionTest()
-{
-}
+LineEditWithAutocorrectionTest::LineEditWithAutocorrectionTest() = default;
 
 void LineEditWithAutocorrectionTest::shouldNotAutocorrectWhenDisabled()
 {
