@@ -1,11 +1,10 @@
 /*
-  SPDX-FileCopyrightText: 2012-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef TRANSLATORUTIL_H
-#define TRANSLATORUTIL_H
+#pragma once
 
 #include <QMap>
 #include <QPair>
@@ -13,7 +12,8 @@
 
 class QComboBox;
 
-namespace PimCommon {
+namespace PimCommon
+{
 class TranslatorUtil
 {
 public:
@@ -22,9 +22,7 @@ public:
     void addPairToMap(QMap<QString, QString> &map, const QPair<QString, QString> &pair);
     void addItemToFromComboBox(QComboBox *combo, const QPair<QString, QString> &pair);
 
-    enum translatorType {
-        GoogleTranslator = 0
-    };
+    enum translatorType { GoogleTranslator = 0 };
 
     enum languages {
         automatic,
@@ -94,4 +92,3 @@ public:
 };
 }
 
-#endif // TRANSLATORUTIL_H
