@@ -2,13 +2,12 @@
   This file is part of libkdepim.
 
   SPDX-FileCopyrightText: 2006 Christian Schaarschmidt <schaarsc@gmx.de>
-  SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2017-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef KDEPIM_KMAILCOMPLETION_H
-#define KDEPIM_KMAILCOMPLETION_H
+#pragma once
 
 #include <KCompletion>
 
@@ -70,4 +69,3 @@ private:
 };
 }
 
-#endif
