@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -17,9 +17,7 @@ CompletionConfigureDialogTest::CompletionConfigureDialogTest(QObject *parent)
 {
 }
 
-CompletionConfigureDialogTest::~CompletionConfigureDialogTest()
-{
-}
+CompletionConfigureDialogTest::~CompletionConfigureDialogTest() = default;
 
 void CompletionConfigureDialogTest::initTestCase()
 {
@@ -30,10 +28,10 @@ void CompletionConfigureDialogTest::shouldHaveDefaultValue()
 {
     PimCommon::CompletionConfigureDialog dlg;
 
-    auto *buttonBox = dlg.findChild<QDialogButtonBox *>(QStringLiteral("buttonbox"));
+    auto buttonBox = dlg.findChild<QDialogButtonBox *>(QStringLiteral("buttonbox"));
     QVERIFY(buttonBox);
 
-    auto *tabWidget = dlg.findChild<QTabWidget *>(QStringLiteral("tabwidget"));
+    auto tabWidget = dlg.findChild<QTabWidget *>(QStringLiteral("tabwidget"));
     QVERIFY(tabWidget);
     QVERIFY(tabWidget->count() > 0);
     for (int i = 0; i < tabWidget->count(); ++i) {
