@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -47,7 +47,7 @@ Q_SIGNALS:
 
 private:
     void slotSetCollectionFilter(const QString &filter);
-    CheckedCollectionWidgetPrivate *const d;
+    std::unique_ptr<CheckedCollectionWidgetPrivate> const d;
 };
 }
 
