@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2014-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -23,9 +23,7 @@ using namespace PimCommon;
 class PimCommon::ManageServerSideSubscriptionJobPrivate
 {
 public:
-    ManageServerSideSubscriptionJobPrivate()
-    {
-    }
+    ManageServerSideSubscriptionJobPrivate() = default;
 
     Akonadi::Collection mCurrentCollection;
     QWidget *mParentWidget = nullptr;
